function [npeak,ninit] = findinit(ir2,reltrig);
% findinit finds the direct sound of an impulse response.
% It gives the index with the peakvalue, "npeak"  and
% the first index before this with a value that is
% greater than the peakvalue*reltrig, "ninit". 
% "reltrig" could typically be 0.001 or smaller, if the
% impulse response is measured and has some noise.
%
% Input parameters:
%   ir2			A squared impulse response
%	reltrig		The relative trigger value that the direct
%					sound will detected by.
% Output parameters:
%	npeak		The index value with the peak of the impulse response
%	ninit		The index value with the direct sound 
% 
% Peter Svensson 020115 (svensson@iet.ntnu.no) 
%
% [npeak,ninit] = findinit(ir2,reltrig);

if any(ir2<0),
	error('The squared impulse response contains values that are smaller than zero. Are you sure the impulse response is squared?')
end
peak = max(ir2);
trigvalue = peak*reltrig;
npeak = find(ir2 == peak);
initvect = find(ir2(1:npeak) > trigvalue);
%i = 1;
%while initvect(i+2) > initvect(i) + 2,
%			i = i+1;
%end
%ninit = initvect(i);
ninit = initvect(1);
